@@ -162,7 +162,7 @@ class BaseTestCase(ExtendBaseTestCase):
         :param new_base: 新的 base，如 'https://new.example.com'
         :return: 替换后的 URL
         """
-        if url.startswith("http"):
+        if url.startswith("http") and "mce.sg" not in url:
             return url
         parsed_url = urlparse(url)
         new_base_parsed = urlparse(new_base)
@@ -205,9 +205,9 @@ class BaseTestCase(ExtendBaseTestCase):
 
     def regenerate_hot_wallet_for_psp(self, participant_code):
         """
-        
+
         :param participant_code: partner或end-user的code
-        :return: 
+        :return:
         """
         # 删除wallet_service中的钱包
         self.logger.info(f"重置{participant_code}热钱包")
@@ -235,7 +235,7 @@ class BaseTestCase(ExtendBaseTestCase):
 
     def regenerate_hot_wallet_for_buyer(self, partner_account, merchant_participant_code, buyer_participant_code):
         """
-        
+
         :param partner_account: partner账号
         :param merchant_participant_code: merchant code
         :param buyer_participant_code: buyer code
