@@ -16,3 +16,9 @@ class BaseScript(__BaseScript):
 
     def default_app(self, app):
         return app or self.app
+
+    def context_set(self, key, value):
+        self.context.set(app=self.app, key=key, value=value)
+
+    def context_get(self, key):
+        return self.context.get(app=self.app, key=key)
\ No newline at end of file
