@@ -40,7 +40,7 @@ class Validate(object):
     def valid(self, validates):
         for valid_item in validates:
             key = list(valid_item.keys())[0]
-            valid_list = [i.strip() for i in valid_item.get(key).split(",")]
+            valid_list = [i.strip() for i in valid_item.get(key).split(",", 1)]
             expression = valid_list[0]
             try:
                 expectant_result = valid_list[1]
